@@ -3,50 +3,73 @@
 
 import argparse
 import logging
+import sys
 from sys import exit as sys_exit
-from sys import stdin, stdout
 
 from lxml.etree import XMLSyntaxError
 
 from . import __version__
 from .debug_settings import DebugSetting
-from .html_report import ReportGenerator
-from .old_html_report_style import OldOSCAPReportGenerator
-from .scap_results_parser import SCAPResultsParser
+from .report_generators import (HTMLReportGenerator,
+                                JSONEverythingReportGenerator,
+                                JSONReportGenerator,
+                                OldStyleHTMLReportGenerator)
+from .scap_results_parser import NotSupportedReportingFormat, SCAPResultsParser
 
 DESCRIPTION = ("Generates an HTML report from an ARF (or XCCDF Result) file with results of "
                "a SCAP-compatible utility scan. Unless the --output option is specified "
                "the report will be written to the standard output.")
-LOG_LEVES_DESCRIPTION = (
-    "LOG LEVELS:\n"
-    "\tDEBUG - Detailed information, typically of interest only for diagnosing problems.\n"
-    "\tINFO - A confirmation that things are working as expected.\n"
-    "\tWARING -  An indication that something unexpected happened, or a signal of"
-    " a possible problem in the future. The software is still working as expected.\n"
-    "\tERROR - Due to a more serious problems, the software has not been able to perform "
-    "its function to the full extent.\n"
-    "\tCRITICAL - A serious error, indicating that the program itself may be unable "
-    "to continue operating.\n"
-)
-DEBUG_FLAGS_DESCRIPTION = (
-    "DEBUG FLAGS:\n"
-    "\tNO-MINIFY - The HTML report will not be minified.\n"
-    "\tBUTTON-SHOW-ALL-RULES - Adds a button to the HTML report for expanding all rules.\n"
-    "\tONLINE-CSS - Use the latest online version of Patternfly CSS/JS in the HTML report\n"
-    "\tBUTTON-SHOW-ALL-RULES-AND-OVAL-TEST-DETAILS - "
-    "Adds a button to the HTML report for expanding all rules and all OVAL test details."
-)
+LOG_LEVELS_DESCRIPTION = """
+LOG LEVELS:
+    DEBUG - Detailed information, typically of interest only for diagnosing problems.
+
+    INFO - A confirmation that things are working as expected.
+
+    WARNING -  An indication that something unexpected happened, or a signal of a possible problem in the future. The software is still working as expected.
+
+    ERROR - Due to a more serious problems, the software has not been able to perform its function to the full extent.
+
+    CRITICAL - A serious error, indicating that the program itself may be unable to continue operating.
+"""
+
+DEBUG_FLAGS_DESCRIPTION = """
+DEBUG FLAGS:
+    NO-MINIFY - The HTML report will not be minified.
+
+    BUTTON-SHOW-ALL-RULES - Adds a button to the HTML report for expanding all rules.
+
+    ONLINE-CSS - Use the latest online version of Patternfly CSS/JS in the HTML report.
+
+    BUTTON-SHOW-ALL-RULES-AND-OVAL-TEST-DETAILS - Adds a button to the HTML report for expanding all rules and all OVAL test details.
+"""
 
 MASSAGE_FORMAT = '%(levelname)s: %(message)s'
-EXPECTED_ERRORS = (XMLSyntaxError, )
+EXPECTED_ERRORS = (XMLSyntaxError, NotSupportedReportingFormat)
 EXIT_FAILURE_CODE = 1
 EXIT_SUCCESS_CODE = 0
 
 
+class CustomHelpFormatter(argparse.RawTextHelpFormatter):
+    def _format_action_invocation(self, action):
+        if not action.option_strings:
+            metavar, = self._metavar_formatter(action, action.dest)(1)
+            return metavar
+
+        parts = []
+        if action.nargs == 0:
+            parts.extend(action.option_strings)
+        else:
+            default = action.dest.upper()
+            args_string = self._format_args(action, default)
+            options_string = ", ".join(action.option_strings)
+            parts.append(f'{options_string} {args_string}')
+        return ',  '.join(parts)
+
+
 def prepare_parser():
     parser = argparse.ArgumentParser(
         prog="oscap-report",
-        formatter_class=argparse.RawTextHelpFormatter,
+        formatter_class=CustomHelpFormatter,
         description=DESCRIPTION,
         add_help=False,
     )
@@ -65,14 +88,14 @@ def prepare_parser():
         'FILE',
         type=argparse.FileType("r"),
         nargs='?',
-        default=stdin,
+        default=sys.stdin,
         help="ARF (XCCDF) file or stdin if not provided.")
     parser.add_argument(
         "-o",
         "--output",
         action="store",
         type=argparse.FileType("wb+", 0),
-        default=stdout,
+        default=sys.stdout,
         help="write the report to a file instead of the standard output.")
     parser.add_argument(
         "--log-file",
@@ -86,15 +109,15 @@ def prepare_parser():
         choices=["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"],
         help=(
             "write debug information to the log up to the LOG_LEVEL."
-            f"\n{LOG_LEVES_DESCRIPTION}")
+            f"\n{LOG_LEVELS_DESCRIPTION}")
     )
     parser.add_argument(
         "-f",
         "--format",
         action="store",
         default="HTML",
-        choices=["HTML", "OLD-STYLE-HTML"],
-        help="FORMAT: %(choices)s (default: %(default)s)."
+        choices=["HTML", "OLD-STYLE-HTML", "JSON", "JSON-EVERYTHING"],
+        help="FORMAT: %(choices)s"
     )
     parser.add_argument(
         "-d",
@@ -104,13 +127,13 @@ def prepare_parser():
         default=[""],
         choices=[
             "NO-MINIFY",
-            "BUTTON-SHOW-ALL-RULES",
             "ONLINE-CSS",
+            "BUTTON-SHOW-ALL-RULES",
             "BUTTON-SHOW-ALL-RULES-AND-OVAL-TEST-DETAILS"
         ],
         help=(
-            "extra HTML generation options for debugging"
-            f"{DEBUG_FLAGS_DESCRIPTION}")
+            "extra HTML generation options for debugging."
+            f"\n{DEBUG_FLAGS_DESCRIPTION}")
     )
     return parser
 
@@ -136,16 +159,22 @@ class CommandLineAPI():  # pylint: disable=R0902
             level=self.log_level.upper()
         )
 
+    def get_report_generator(self, report_parser):
+        dict_of_report_generators = {
+            "HTML": HTMLReportGenerator,
+            "OLD-STYLE-HTML": OldStyleHTMLReportGenerator,
+            "JSON": JSONReportGenerator,
+            "JSON-EVERYTHING": JSONEverythingReportGenerator,
+        }
+        return dict_of_report_generators[self.output_format](report_parser)
+
     def generate_report(self, report_parser):
         logging.info("Generate report")
-        if self.output_format == "OLD-STYLE-HTML":
-            report_generator = OldOSCAPReportGenerator(report_parser)
-            return report_generator.generate_html_report()
-        report_generator = ReportGenerator(report_parser)
+        report_generator = self.get_report_generator(report_parser)
 
         self.debug_setting.update_settings_with_debug_flags(self.debug_flags)
 
-        return report_generator.generate_html_report(self.debug_setting)
+        return report_generator.generate_report(self.debug_setting)
 
     def load_file(self):
         logging.info("Loading file: %s", self.report_file)
