@@ -1,16 +1,25 @@
 # Copyright 2022, Red Hat, Inc.
 # SPDX-License-Identifier: LGPL-2.1-or-later
 
-import pytest
+import logging
+from contextlib import nullcontext as does_not_raise
 
-from openscap_report.scap_results_parser import SCAPResultsParser
-from openscap_report.scap_results_parser.data_structures import Report, Rule
+import pytest
+from lxml.etree import XMLSyntaxError
+
+from openscap_report.scap_results_parser import ARF_SCHEMAS_PATH
+from openscap_report.scap_results_parser.data_structures import (Report, Rule,
+                                                                 RuleWarning)
+from openscap_report.scap_results_parser.exceptions import \
+    NotSupportedReportingFormat
+from openscap_report.scap_results_parser.parsers.report_parser import \
+    ReportParser
 
 from ..constants import (PATH_TO_ARF, PATH_TO_ARF_SCANNED_ON_CONTAINER,
                          PATH_TO_ARF_WITH_MULTI_CHECK,
                          PATH_TO_ARF_WITH_OS_CPE_CHECK,
                          PATH_TO_ARF_WITHOUT_INFO,
-                         PATH_TO_ARF_WITHOUT_SYSTEM_DATA,
+                         PATH_TO_ARF_WITHOUT_SYSTEM_DATA, PATH_TO_EMPTY_FILE,
                          PATH_TO_EMPTY_XML_FILE, PATH_TO_REMEDIATIONS_SCRIPTS,
                          PATH_TO_RULE_AND_CPE_CHECK_ARF,
                          PATH_TO_RULE_AND_CPE_CHECK_XCCDF,
@@ -20,14 +29,9 @@ from ..constants import (PATH_TO_ARF, PATH_TO_ARF_SCANNED_ON_CONTAINER,
                          PATH_TO_SIMPLE_RULE_PASS_XCCDF, PATH_TO_XCCDF,
                          PATH_TO_XCCDF_WITH_MULTI_CHECK,
                          PATH_TO_XCCDF_WITHOUT_INFO,
-                         PATH_TO_XCCDF_WITHOUT_SYSTEM_DATA)
-
-
-def get_parser(file_path):
-    xml_data = None
-    with open(file_path, "r", encoding="utf-8") as xml_report:
-        xml_data = xml_report.read().encode()
-    return SCAPResultsParser(xml_data)
+                         PATH_TO_XCCDF_WITHOUT_SYSTEM_DATA, PATH_TO_XML_FILE)
+from ..test_utils import (BASIC_REPORT, DEFAULT_RULES, get_benchmark,
+                          get_parser, get_root, get_rules, get_test_results)
 
 
 @pytest.mark.unit_test
@@ -46,35 +50,57 @@ def get_parser(file_path):
     (PATH_TO_RULE_AND_CPE_CHECK_XCCDF, False),
     (PATH_TO_XCCDF_WITHOUT_INFO, False),
     (PATH_TO_XCCDF_WITHOUT_SYSTEM_DATA, False),
-    (PATH_TO_EMPTY_XML_FILE, False),
 ])
 def test_validation(file_path, result):
     parser = get_parser(file_path)
-    assert parser.validate(parser.arf_schemas_path) == result
+    assert parser.validate(ARF_SCHEMAS_PATH) == result
+
+
+@pytest.mark.unit_test
+@pytest.mark.parametrize("file_path, expectation, e_msg", [
+    (PATH_TO_ARF, does_not_raise(), ""),
+    (PATH_TO_XCCDF, does_not_raise(), "input is the XCCDF"),
+    (PATH_TO_EMPTY_XML_FILE, pytest.raises(NotSupportedReportingFormat), "isn't a valid"),
+    (PATH_TO_EMPTY_FILE, pytest.raises(XMLSyntaxError), "empty"),
+    (PATH_TO_XML_FILE, pytest.raises(NotSupportedReportingFormat), "isn't a valid"),
+])
+def test_parsers_init(file_path, expectation, e_msg, caplog):
+    caplog.set_level(logging.WARNING)
+    with expectation as excinfo:
+        get_parser(file_path)
+    if excinfo is not None:
+        assert e_msg in str(excinfo.value)
+    else:
+        assert e_msg in str(caplog.text)
 
 
 @pytest.mark.unit_test
 @pytest.mark.parametrize("file_path, number_of_cpe_platforms, os_cpe_platform", [
-    (PATH_TO_ARF, 13, "cpe:/o:fedoraproject:fedora:32"),
-    (PATH_TO_XCCDF, 13, "cpe:/o:fedoraproject:fedora:32"),
-    (PATH_TO_SIMPLE_RULE_PASS_ARF, 0, ""),
-    (PATH_TO_SIMPLE_RULE_FAIL_ARF, 0, ""),
-    (PATH_TO_ARF_WITHOUT_INFO, 0, ""),
-    (PATH_TO_ARF_WITHOUT_SYSTEM_DATA, 0, ""),
-    (PATH_TO_ARF_SCANNED_ON_CONTAINER, 6, "cpe:/o:fedoraproject:fedora:35"),
-    (PATH_TO_RULE_AND_CPE_CHECK_ARF, 1, "cpe:/o:example:applicable:5"),
-    (PATH_TO_ARF_WITH_OS_CPE_CHECK, 0, "cpe:/o:fedoraproject:fedora:1"),
-    (PATH_TO_SIMPLE_RULE_PASS_XCCDF, 0, ""),
-    (PATH_TO_SIMPLE_RULE_FAIL_XCCDF, 0, ""),
-    (PATH_TO_XCCDF_WITHOUT_INFO, 0, ""),
-    (PATH_TO_XCCDF_WITHOUT_SYSTEM_DATA, 0, ""),
-    (PATH_TO_RULE_AND_CPE_CHECK_XCCDF, 1, "cpe:/o:example:applicable:5"),
+    (PATH_TO_ARF, 13, {"cpe:/o:fedoraproject:fedora:32": True}),
+    (PATH_TO_XCCDF, 13, {"cpe:/o:fedoraproject:fedora:32": True}),
+    (PATH_TO_SIMPLE_RULE_PASS_ARF, 0, {}),
+    (PATH_TO_SIMPLE_RULE_FAIL_ARF, 0, {}),
+    (PATH_TO_ARF_WITHOUT_INFO, 0, {}),
+    (PATH_TO_ARF_WITHOUT_SYSTEM_DATA, 0, {}),
+    (PATH_TO_ARF_SCANNED_ON_CONTAINER, 6, {
+        'cpe:/o:fedoraproject:fedora:35': True,
+        'cpe:/o:fedoraproject:fedora:34': True,
+        'cpe:/o:fedoraproject:fedora:33': True
+    }),
+    (PATH_TO_RULE_AND_CPE_CHECK_ARF, 1, {}),
+    (PATH_TO_ARF_WITH_OS_CPE_CHECK, 0, {"cpe:/o:fedoraproject:fedora:1": False}),
+    (PATH_TO_SIMPLE_RULE_PASS_XCCDF, 0, {}),
+    (PATH_TO_SIMPLE_RULE_FAIL_XCCDF, 0, {}),
+    (PATH_TO_XCCDF_WITHOUT_INFO, 0, {}),
+    (PATH_TO_XCCDF_WITHOUT_SYSTEM_DATA, 0, {}),
+    (PATH_TO_RULE_AND_CPE_CHECK_XCCDF, 1, {}),
 ])
 def test_get_profile_info(file_path, number_of_cpe_platforms, os_cpe_platform):
-    parser = get_parser(file_path)
-    report = parser.get_profile_info()
-    assert len(report.cpe_platforms) == number_of_cpe_platforms
-    assert report.platform == os_cpe_platform
+    root = get_root(file_path)
+    report_parser = ReportParser(root, get_test_results(root), get_benchmark(root))
+    report = report_parser.get_report()
+    assert len(report.scan_result.cpe_platforms) == number_of_cpe_platforms
+    assert report.profile_info.cpe_platforms_for_profile == os_cpe_platform
 
 
 @pytest.mark.unit_test
@@ -95,10 +121,9 @@ def test_get_profile_info(file_path, number_of_cpe_platforms, os_cpe_platform):
     (PATH_TO_RULE_AND_CPE_CHECK_XCCDF, 3),
 ])
 def test_get_info_about_rules_in_profile(file_path, number_of_rules):
-    parser = get_parser(file_path)
-    parser.process_groups_or_rules()
-    assert len(parser.rules.keys()) == number_of_rules
-    for rule in parser.rules.values():
+    rules = get_rules(file_path)
+    assert len(rules.keys()) == number_of_rules
+    for rule in rules.values():
         assert isinstance(rule, Rule)
 
 
@@ -111,11 +136,11 @@ def test_parse_report(file_path, contains_oval_tree):
     parser = get_parser(file_path)
     report = parser.parse_report()
     assert isinstance(report, Report)
-    assert report.profile_name is not None
+    assert report.profile_info.profile_id is not None
     assert report.rules is not None
     rule_id = "xccdf_org.ssgproject.content_rule_accounts_passwords_pam_faillock_deny"
     assert isinstance(report.rules[rule_id], Rule)
-    assert (report.rules[rule_id].oval_tree is not None) == contains_oval_tree
+    assert (report.rules[rule_id].oval_definition is not None) == contains_oval_tree
 
 
 @pytest.mark.unit_test
@@ -126,10 +151,9 @@ def test_parse_report(file_path, contains_oval_tree):
     (PATH_TO_ARF_WITH_MULTI_CHECK, True),
 ])
 def test_multi_check(file_path, contains_rules_some_multi_check_rule):
-    parser = get_parser(file_path)
-    parser.process_groups_or_rules()
+    rules = get_rules(file_path)
     result = False
-    for rule in parser.rules.values():
+    for rule in rules.values():
         if rule.multi_check:
             result = True
     assert result == contains_rules_some_multi_check_rule
@@ -180,9 +204,7 @@ def test_multi_check(file_path, contains_rules_some_multi_check_rule):
     ),
 ])
 def test_description(rule, result):
-    parser = get_parser(PATH_TO_ARF)
-    parser.process_groups_or_rules()
-    assert parser.rules[rule].description == result
+    assert DEFAULT_RULES[rule].description == result
 
 
 @pytest.mark.unit_test
@@ -227,16 +249,16 @@ def test_description(rule, result):
     )
 ])
 def test_rationale(rule, result):
-    parser = get_parser(PATH_TO_ARF)
-    parser.process_groups_or_rules()
-    assert parser.rules[rule].rationale == result
+    assert DEFAULT_RULES[rule].rationale == result
 
 
 @pytest.mark.unit_test
 @pytest.mark.parametrize("rule, result", [
     (
         "xccdf_org.ssgproject.content_rule_prefer_64bit_os",
-        ["There is no remediation besides installing a 64-bit operating system."]
+        [RuleWarning(
+            "There is no remediation besides installing a 64-bit operating system.", "general"
+        )]
     ),
     (
         "xccdf_org.ssgproject.content_rule_dconf_gnome_screensaver_lock_enabled",
@@ -249,26 +271,24 @@ def test_rationale(rule, result):
     (
         "xccdf_org.ssgproject.content_rule_sudoers_explicit_command_args",
         [
-            (
+            RuleWarning(
                 "This rule doesn&#x27;t come with a remediation, as absence of arguments in"
                 " the user spec doesn&#x27;t mean that the command is intended to be executed "
-                "with no arguments."
+                "with no arguments.", "general"
             ),
-            (
+            RuleWarning(
                 "The rule can produce false findings when an argument contains a"
                 " comma - sudoers syntax allows comma escaping using backslash, but"
                 " the check doesn&#x27;t support that. For example,"
                 " <code>root ALL=(ALL) echo 1\\,2</code> allows root to execute"
                 " <code>echo 1,2</code>, but the check would interpret it as two commands "
-                "<code>echo 1\\</code> and <code>2</code>."
+                "<code>echo 1\\</code> and <code>2</code>.", "general"
             )
         ]
     )
 ])
 def test_warnings(rule, result):
-    parser = get_parser(PATH_TO_ARF)
-    parser.process_groups_or_rules()
-    assert parser.rules[rule].warnings == result
+    assert DEFAULT_RULES[rule].warnings == result
 
 
 @pytest.mark.unit_test
@@ -296,12 +316,65 @@ def test_warnings(rule, result):
     )
 ])
 def test_remediations(rule, remediation_id, scripts):
-    parser = get_parser(PATH_TO_ARF)
-    parser.process_groups_or_rules()
-    for remediation in parser.rules[rule].remediations:
+    if DEFAULT_RULES[rule].remediations == scripts is None:
+        return
+
+    for remediation in DEFAULT_RULES[rule].remediations:
         assert remediation.remediation_id == remediation_id
         assert remediation.system in scripts
         path = PATH_TO_REMEDIATIONS_SCRIPTS / str(scripts[remediation.system])
         with open(path, "r", encoding="utf-8") as script:
             data = script.read()
             assert data == remediation.fix
+
+
+@pytest.mark.unit_test
+@pytest.mark.parametrize("rule, oval_def_id, title, description, version", [
+    (
+        "xccdf_org.ssgproject.content_rule_prefer_64bit_os",
+        "oval:ssg-prefer_64bit_os:def:1",
+        "Prefer to use a 64-bit Operating System when supported",
+        "Check if the system supports a 64-bit Operating System",
+        "1"
+    ),
+    (
+        "xccdf_org.ssgproject.content_rule_dconf_gnome_screensaver_lock_enabled",
+        "oval:ssg-dconf_gnome_screensaver_lock_enabled:def:1",
+        "Enable GNOME3 Screensaver Lock After Idle Period",
+        "Idle activation of the screen lock should be enabled.",
+        "2",
+    ),
+    (
+        "xccdf_org.ssgproject.content_rule_installed_OS_is_FIPS_certified",
+        "oval:ssg-installed_OS_is_FIPS_certified:def:1",
+        "The Installed Operating System Is FIPS 140-2 Certified",
+        (
+            "\n          The operating system installed on the system is"
+            " a certified operating system that meets FIPS 140-2 requirements.\n      "
+        ),
+        "1",
+    ),
+    (
+        "xccdf_org.ssgproject.content_rule_dconf_db_up_to_date",
+        "oval:ssg-dconf_db_up_to_date:def:1",
+        "Make sure that the dconf databases are up-to-date with regards to respective keyfiles",
+        "Make sure that the dconf databases are up-to-date with regards to respective keyfiles.",
+        "2",
+    ),
+    (
+        "xccdf_org.ssgproject.content_rule_dconf_gnome_screensaver_lock_delay",
+        "oval:ssg-dconf_gnome_screensaver_lock_delay:def:1",
+        "Set GNOME3 Screensaver Lock Delay After Activation Period",
+        (
+            "Idle activation of the screen lock should be enabled immediately or"
+            "\n      after a delay."
+        ),
+        "2",
+    )
+])
+def test_oval_definition_in_rules(rule, oval_def_id, title, description, version):
+    oval_definition = BASIC_REPORT.rules[rule].oval_definition
+    assert oval_definition.definition_id == oval_def_id
+    assert oval_definition.title == title
+    assert oval_definition.version == version
+    assert oval_definition.description == description
